@@ -1,12 +1,13 @@
-package TableDataRole::Spec::Basic;
-
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-01'; # DATE
-our $DIST = 'TableData'; # DIST
-our $VERSION = '0.2.1'; # VERSION
+ ## no critic: TestingAndDebugging::RequireUseStrict
+ package TableDataRole::Spec::Basic;
 
 use Role::Tiny;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-11-29'; # DATE
+our $DIST = 'TableData'; # DIST
+our $VERSION = '0.2.2'; # VERSION
+
 # constructor
 requires 'new';
 
@@ -90,7 +91,7 @@ TableDataRole::Spec::Basic - Basic interface for all TableData::* modules
 
 =head1 VERSION
 
-This document describes version 0.2.1 of TableDataRole::Spec::Basic (from Perl distribution TableData), released on 2021-06-01.
+This document describes version 0.2.2 of TableDataRole::Spec::Basic (from Perl distribution TableData), released on 2022-11-29.
 
 =head1 DESCRIPTION
 
@@ -329,6 +330,37 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableData>
 
 Source repository is at L<https://github.com/perlancar/perl-TableData>.
 
+=head1 SEE ALSO
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableData>
@@ -337,17 +369,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
